/**
 * CMI : Cluster Method Invocation
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: cmi@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 * --------------------------------------------------------------------------
 * $Id: Domain.java 2330 2009-05-26 10:26:52Z loris $
 * --------------------------------------------------------------------------
 */

package org.ow2.cmi.controller.server;

import java.io.Serializable;

/**
 * Wraps the information related to a server in a domain.
 * @author Loris Bouzonnet
 */
public class Domain implements Serializable {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -8617915643237716692L;

    /**
     * Domain name.
     */
    private final String name;

    /**
     * Server port in this domain.
     */
    private final short port;


    /**
     * Wraps a domain name with a server port in this domain.
     * @param name the domain name.
     * @param port the server port in this domain.
     */
    public Domain(final String name, final short port) {
        this.name = name;
        this.port = port;
    }

    /**
     * @return the domain name.
     */
    public String getName() {
        return name;
    }

    /**
     * @return the server port in this domain.
     */
    public short getPort() {
        return port;
    }

    @Override
    public String toString() {
        return "Domain[name=" + name + ", port=" + port + "]";
    }
}
